<?php

namespace Drupal\janrain_connect_admin_services\Service;

use Drupal\janrain_connect\Service\JanrainConnectConnector;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Class: JanrainConnectAdminServicesCalls.
 */
class JanrainConnectAdminServicesCalls {

  use StringTranslationTrait;

  /**
   * JanrainConnectConnector.
   *
   * @var \Drupal\janrain_connect\Service\JanrainConnectConnector
   */
  protected $janrainConnector;

  /**
   * The logger factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactory $config_factory, LoggerChannelFactoryInterface $logger_factory, JanrainConnectConnector $janrain_connector) {
    $this->config = $config_factory->get('janrain_connect_super_admin.settings');
    $this->logger = $logger_factory->get('janrain_connect');
    $this->janrainConnector = $janrain_connector;
  }

  /**
   * Find User.
   */
  public function findUser($filter) {

    $auth_id = $this->config->get('auth_id');
    $auth_secret = $this->config->get('auth_secret');

    $response = $this->janrainConnector->findUser($filter, $auth_id, $auth_secret);

    if (empty($response) || empty($response['results'])) {
      return FALSE;
    }

    return $response;
  }

  /**
   * Entity Delete on Janrain.
   *
   * @param string $uuid
   *   The unique identifier given to the entity.
   *
   * @return array
   *   Janrain api return.
   */
  public function entityDelete($uuid) {
    $result = $this->janrainConnector->janrainApi->entityDelete(
      $uuid,
      $this->janrainConnector->config->get('entity_type')
    );

    $this->janrainConnector->janrainConnectValidate->validateResponse($result);

    return $result;
  }

}
